#
# spec file for package swig
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           swig
Version:        2.0.11
Release:        0
Summary:        Simplified Wrapper and Interface Generator
License:        GPL-3.0+ and BSD-3-Clause
Group:          Development/Languages/C and C++
Url:            http://www.swig.org/
Source:         http://sourceforge.net/projects/swig/files/swig/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.rpmlintrc
# Fix the return type in declaration of caml_array_length
Patch9:         swig-fix_ocaml_type.patch
# Ruby 2.0 encodes to UTF-8, SWIG to US-ASCII-8BIT, kkaempf@suse.de
Patch10:        ruby-2.0-encoding-utf8.patch
# Fix SWIG object tracking to use C hash, not Ruby Hash, kkaempf@suse.de
Patch11:        0001-Fix-Ruby-tracking-code-to-use-C-hash.patch
# Ruby 1.8.6 (SLE 10) differs in object tracking, kkaempf@suse.de
Patch12:        ruby-1.8.6-newobject.patch
# PATCH-FIX-UPSTREAM swig-lua-fix-void-return-for-int-functions.patch bnc#843310 badshah400@gmail.com -- Fix functions returning void when int is expected for lua bindings
Patch13:        swig-lua-fix-void-return-for-int-functions.patch
# PATCH-FIX-UPSTREAM swig-support-octave-3.8.0.patch badshah400@gmail.com -- Support octave 3.8.0 (this fixes octave 3.8.0 bindings of several packages failing to build in Factory such as mathgl, plplot, etc.), patch taken from upstream and rebased for current version.
Patch14:        swig-support-octave-3.8.0.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pcre-devel
BuildRequires:  perl
BuildRequires:  python-devel
%if 0%{?rhel_version} > 0
BuildRequires:  -vim
%endif
%if 0%{?fedora} + 0%{?rhel_version} + 0%{?centos_version} > 0
%define docpath %{_docdir}/%{name}-%{version}
BuildRequires:  pkgconfig
BuildRequires:  ruby
%if 0%{?rhel_version} < 600 && 0%{?centos_version} < 600
# not available on RHEL-6
BuildRequires:  ruby-devel
%endif
%if 0%{?fedora} > 0 || 0%{?rhel_version} >= 600  ||0%{?centos_version} >= 600
BuildRequires:  perl-Test-Simple
BuildRequires:  perl-devel
%endif
%endif
%if 0%{?suse_version} > 0
%define docpath %{_docdir}/%{name}
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
# SLE9
%if 0%{?suse_version} < 920
BuildRequires:  pkgconfig
BuildRequires:  ruby
%else
BuildRequires:  pkg-config
# SLE10 and up
BuildRequires:  ruby-devel
%endif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.

%package doc
Summary:        SWIG Manual
License:        BSD-3-Clause
Group:          Documentation/Man
Requires:       swig
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.

This package contains the SWIG manual.

%package examples
Summary:        SWIG example files
License:        BSD-3-Clause
Group:          Documentation/Howto
Requires:       swig

%description examples
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.

This package contains SWIG examples, useful both for testing and
understandig SWIG usage.

%prep
%setup -q
%if 0%{?suse_version} == 1010
%patch12 -p1
%endif
# Ruby 1.9 for openSUSE 12.x
%if 0%{?suse_version} >= 1220
%patch11 -p1
# Ruby 2.0 for openSUSE 13.1
%if 0%{?suse_version} > 1230
%patch10 -p1
%endif
%endif
%patch9
%patch13 -p1
%patch14 -p1

%build
%configure --disable-ccache
make %{?_smp_mflags}

%check
make check

%install
make install DESTDIR=%{buildroot}

install -d %{buildroot}%{docpath}
cp -a TODO ANNOUNCE CHANGES* LICENSE README Doc/{Devel,Manual} \
	%{buildroot}%{docpath}
install -d %{buildroot}%{_libdir}/swig
cp -a Examples %{buildroot}%{_libdir}/swig/examples
rm -rf %{buildroot}%{_libdir}/swig/examples/test-suite

# rm files that are not needed for running or rebuilding the examples
find %{buildroot}%{_libdir}/swig \
	-name '*.dsp' -o -name '*.vcproj' -o -name '*.sln' -o \
	-name '*.o' -o -name '*_wrap.c' | xargs rm

# fix perms
chmod -x %{buildroot}%{docpath}/Manual/*
find %{buildroot}%{_libdir}/swig -name '*.h' -perm +111 | \
	xargs --no-run-if-empty chmod -x
ln -s %{_libdir}/swig/examples %{buildroot}%{docpath}/Examples

%if 0%{?suse_version} > 1010
%fdupes %{buildroot}
%endif

%files
%defattr(644,root,root,755)
%dir %{docpath}
%{docpath}/[A-Z][A-Z]*
%{_datadir}/swig
%attr(755,root,root) %{_bindir}/swig

%files doc
%defattr(-,root,root)
%{docpath}/Devel
%{docpath}/Manual

%files examples
%defattr(-,root,root)
%{docpath}/Examples
%{_libdir}/swig

%changelog
